@@ -38,18 +38,18 @@ public:
 
 	KGpgNode *nodeForIndex(const QModelIndex &index) const;
 
-	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-	virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-	virtual bool hasChildren(const QModelIndex &parent) const;
-	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    bool hasChildren(const QModelIndex &parent) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
 	bool showUntrusted() const;
 	void setShowUntrusted(const bool b);
 
 protected:
-	virtual bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
-	virtual int columnCount(const QModelIndex &) const;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    int columnCount(const QModelIndex &) const override;
 
 	KGpgItemModel *m_model;
 
@@ -62,15 +62,15 @@ class SelectSecretKeyProxyModel: public SelectKeyProxyModel
 public:
 	explicit SelectSecretKeyProxyModel(QObject *parent);
 
-	virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-	virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-	virtual bool hasChildren(const QModelIndex &parent) const;
-	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    bool hasChildren(const QModelIndex &parent) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
 protected:
-	virtual bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
-	virtual int columnCount(const QModelIndex &) const;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    int columnCount(const QModelIndex &) const override;
 };
 
 #endif
